@@ -1,6 +1,5 @@
 from ipfabric_diagrams.input_models.graph_parameters import ICMP
 
-
 ECHO_REPLY = ICMP(type=0, code=0)
 NET_UNREACHABLE = ICMP(type=3, code=0)
 HOST_UNREACHABLE = ICMP(type=3, code=1)
@@ -45,3 +44,17 @@ DECOMPRESSION_FAILED = ICMP(type=40, code=2)
 DECRYPTION_FAILED = ICMP(type=40, code=3)
 NEED_AUTHENTICATION = ICMP(type=40, code=4)
 NEED_AUTHORIZATION = ICMP(type=40, code=5)
+
+__all__ = ["ECHO_REPLY", "NET_UNREACHABLE", "HOST_UNREACHABLE", "PROTOCOL_UNREACHABLE", "PORT_UNREACHABLE",
+           "FRAGMENTATION_NEEDED", "SOURCE_ROUTE_FAILED", "DESTINATION_NETWORK_UNKNOWN", "DESTINATION_HOST_UNKNOWN",
+           "SOURCE_HOST_ISOLATED", "DESTINATION_NETWORK_ADMIN_PROHIBITED", "DESTINATION_HOST_ADMIN_PROHIBITED",
+           "DESTINATION_NETWORK_UNREACHABLE_FOR_TOS", "DESTINATION_HOST_UNREACHABLE_FOR_TOS",
+           "COMMUNICATION_ADMINISTRATIVELY_PROHIBITED", "HOST_PRECEDENCE_VIOLATION", "PRECEDENCE_CUTOFF_IN_EFFECT",
+           "SOURCE_QUENCH", "REDIRECT_DATAGRAM_FOR_THE_NETWORK", "REDIRECT_DATAGRAM_FOR_THE_HOST",
+           "REDIRECT_DATAGRAM_FOR_THE_TOS_AND_NETWORK", "REDIRECT_DATAGRAM_FOR_THE_TOS_AND_HOST",
+           "ALTERNATE_ADDRESS_FOR_HOST", "ECHO_REQUEST", "NORMAL_ROUTER_ADVERTISEMENT", "DOES_NOT_ROUTE_COMMON_TRAFFIC",
+           "ROUTER_SOLICITATION", "TIME_TO_LIVE_EXCEEDED_IN_TRANSIT", "FRAGMENT_REASSEMBLY_TIME_EXCEEDED",
+           "POINTER_INDICATES_THE_ERROR", "MISSING_A_REQUIRED_OPTION", "BAD_LENGTH", "TIMESTAMP_REQUEST",
+           "TIMESTAMP_REPLY", "INFORMATION_REQUEST", "INFORMATION_REPLY", "MASK_REQUEST", "MASK_REPLY", "BAD_SPI",
+           "AUTHENTICATION_FAILED", "DECOMPRESSION_FAILED", "DECRYPTION_FAILED", "NEED_AUTHENTICATION",
+           "NEED_AUTHORIZATION"]
